@@ -656,15 +656,6 @@ class BertTextClassifierTrainBatchOp(BatchOperator):
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
-    def setModelPath(self, val):
-        return self._add_param('modelPath', val)
-
-    def setTaskName(self, val):
-        return self._add_param('taskName', val)
-
-    def setTaskType(self, val):
-        return self._add_param('taskType', val)
-
     def setTextCol(self, val):
         return self._add_param('textCol', val)
 
@@ -707,12 +698,6 @@ class BertTextClassifierTrainBatchOp(BatchOperator):
     def setRemoveCheckpointBeforeTraining(self, val):
         return self._add_param('removeCheckpointBeforeTraining', val)
 
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setTextPairCol(self, val):
-        return self._add_param('textPairCol', val)
-
 
 class BertTextEmbeddingBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.nlp.BertTextEmbeddingBatchOp'
@@ -724,9 +709,6 @@ class BertTextEmbeddingBatchOp(BatchOperator):
         super(BertTextEmbeddingBatchOp, self).__init__(*args, **kwargs)
         pass
 
-    def setModelPath(self, val):
-        return self._add_param('modelPath', val)
-
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -788,18 +770,12 @@ class BertTextPairClassifierTrainBatchOp(BatchOperator):
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
-    def setModelPath(self, val):
-        return self._add_param('modelPath', val)
-
-    def setTaskName(self, val):
-        return self._add_param('taskName', val)
-
-    def setTaskType(self, val):
-        return self._add_param('taskType', val)
-
     def setTextCol(self, val):
         return self._add_param('textCol', val)
 
+    def setTextPairCol(self, val):
+        return self._add_param('textPairCol', val)
+
     def setBatchSize(self, val):
         return self._add_param('batchSize', val)
 
@@ -839,12 +815,6 @@ class BertTextPairClassifierTrainBatchOp(BatchOperator):
     def setRemoveCheckpointBeforeTraining(self, val):
         return self._add_param('removeCheckpointBeforeTraining', val)
 
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setTextPairCol(self, val):
-        return self._add_param('textPairCol', val)
-
 
 class BertTextPairRegressorPredictBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.regression.BertTextPairRegressorPredictBatchOp'
@@ -879,18 +849,12 @@ class BertTextPairRegressorTrainBatchOp(BatchOperator):
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
-    def setModelPath(self, val):
-        return self._add_param('modelPath', val)
-
-    def setTaskName(self, val):
-        return self._add_param('taskName', val)
-
-    def setTaskType(self, val):
-        return self._add_param('taskType', val)
-
     def setTextCol(self, val):
         return self._add_param('textCol', val)
 
+    def setTextPairCol(self, val):
+        return self._add_param('textPairCol', val)
+
     def setBatchSize(self, val):
         return self._add_param('batchSize', val)
 
@@ -930,12 +894,6 @@ class BertTextPairRegressorTrainBatchOp(BatchOperator):
     def setRemoveCheckpointBeforeTraining(self, val):
         return self._add_param('removeCheckpointBeforeTraining', val)
 
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setTextPairCol(self, val):
-        return self._add_param('textPairCol', val)
-
 
 class BertTextRegressorPredictBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.regression.BertTextRegressorPredictBatchOp'
@@ -970,15 +928,6 @@ class BertTextRegressorTrainBatchOp(BatchOperator):
     def setLabelCol(self, val):
         return self._add_param('labelCol', val)
 
-    def setModelPath(self, val):
-        return self._add_param('modelPath', val)
-
-    def setTaskName(self, val):
-        return self._add_param('taskName', val)
-
-    def setTaskType(self, val):
-        return self._add_param('taskType', val)
-
     def setTextCol(self, val):
         return self._add_param('textCol', val)
 
@@ -1021,12 +970,6 @@ class BertTextRegressorTrainBatchOp(BatchOperator):
     def setRemoveCheckpointBeforeTraining(self, val):
         return self._add_param('removeCheckpointBeforeTraining', val)
 
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setTextPairCol(self, val):
-        return self._add_param('textPairCol', val)
-
 
 class BinarizerBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.feature.BinarizerBatchOp'
