@@ -300,7 +300,8 @@ def dataframe_to_operator_memory(df, schema_str, op_type):
         if j_col_type.toString() == "Boolean":
             df_copy[col_name] = df_copy[col_name].apply(lambda x: x if x is None else str(x).lower())
 
-    content = df_copy.to_csv(index=False, header=False)
+    # Must set date_format, so Timestamp#valueOf in Java side works.
+    content = df_copy.to_csv(index=False, header=False, date_format="%Y-%m-%d %H:%M:%S.%f")
     j_multi_line_csv_parser = get_java_class("com.alibaba.alink.common.utils.MultiLineCsvParser")
 
     line_terminator = os.linesep
