@@ -8,6 +8,569 @@ from ..lazy.has_lazy_print_train_info import HasLazyPrintTrainInfo
 from ..local_predictor import LocalPredictable
 
 
+class DecisionTreeRegressor(Estimator, HasLazyPrintModelInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.regression.DecisionTreeRegressor'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DecisionTreeRegressor, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setCreateTreeMode(self, val):
+        return self._add_param('createTreeMode', val)
+
+    def setMaxBins(self, val):
+        return self._add_param('maxBins', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMaxMemoryInMB(self, val):
+        return self._add_param('maxMemoryInMB', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+
+class DocCountVectorizer(Estimator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocCountVectorizer'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DocCountVectorizer, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setFeatureType(self, val):
+        return self._add_param('featureType', val)
+
+    def setMaxDF(self, val):
+        return self._add_param('maxDF', val)
+
+    def setMinDF(self, val):
+        return self._add_param('minDF', val)
+
+    def setMinTF(self, val):
+        return self._add_param('minTF', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVocabSize(self, val):
+        return self._add_param('vocabSize', val)
+
+
+class DocCountVectorizerModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocCountVectorizerModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DocCountVectorizerModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class DocHashCountVectorizer(Estimator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocHashCountVectorizer'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DocHashCountVectorizer, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setFeatureType(self, val):
+        return self._add_param('featureType', val)
+
+    def setMinDF(self, val):
+        return self._add_param('minDF', val)
+
+    def setMinTF(self, val):
+        return self._add_param('minTF', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumFeatures(self, val):
+        return self._add_param('numFeatures', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class DocHashCountVectorizerModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.DocHashCountVectorizerModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DocHashCountVectorizerModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class EqualWidthDiscretizer(Estimator, HasLazyPrintModelInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.EqualWidthDiscretizer'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(EqualWidthDiscretizer, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setDropLast(self, val):
+        return self._add_param('dropLast', val)
+
+    def setEncode(self, val):
+        return self._add_param('encode', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setLeftOpen(self, val):
+        return self._add_param('leftOpen', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumBuckets(self, val):
+        return self._add_param('numBuckets', val)
+
+    def setNumBucketsArray(self, val):
+        return self._add_param('numBucketsArray', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class EqualWidthDiscretizerModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.EqualWidthDiscretizerModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(EqualWidthDiscretizerModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setDropLast(self, val):
+        return self._add_param('dropLast', val)
+
+    def setEncode(self, val):
+        return self._add_param('encode', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class ExtractMfccFeature(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.audio.ExtractMfccFeature'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ExtractMfccFeature, self).__init__(*args, **kwargs)
+        pass
+
+    def setSampleRate(self, val):
+        return self._add_param('sampleRate', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHopSecond(self, val):
+        return self._add_param('hopSecond', val)
+
+    def setNMfcc(self, val):
+        return self._add_param('nMfcc', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setWindowSecond(self, val):
+        return self._add_param('windowSecond', val)
+
+
+class FeatureHasher(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.FeatureHasher'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FeatureHasher, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setNumFeatures(self, val):
+        return self._add_param('numFeatures', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class FmClassificationModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.classification.FmClassificationModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FmClassificationModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
+class FmClassifier(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.classification.FmClassifier'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FmClassifier, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setEpsilon(self, val):
+        return self._add_param('epsilon', val)
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setInitStdev(self, val):
+        return self._add_param('initStdev', val)
+
+    def setLambda0(self, val):
+        return self._add_param('lambda0', val)
+
+    def setLambda1(self, val):
+        return self._add_param('lambda1', val)
+
+    def setLambda2(self, val):
+        return self._add_param('lambda2', val)
+
+    def setLearnRate(self, val):
+        return self._add_param('learnRate', val)
+
+    def setMinibatchSize(self, val):
+        return self._add_param('minibatchSize', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumEpochs(self, val):
+        return self._add_param('numEpochs', val)
+
+    def setNumFactor(self, val):
+        return self._add_param('numFactor', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWithIntercept(self, val):
+        return self._add_param('withIntercept', val)
+
+    def setWithLinearItem(self, val):
+        return self._add_param('withLinearItem', val)
+
+
+class FmItemsPerUserRecommender(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.recommendation.FmItemsPerUserRecommender'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FmItemsPerUserRecommender, self).__init__(*args, **kwargs)
+        pass
+
+    def setRecommCol(self, val):
+        return self._add_param('recommCol', val)
+
+    def setUserCol(self, val):
+        return self._add_param('userCol', val)
+
+    def setExcludeKnown(self, val):
+        return self._add_param('excludeKnown', val)
+
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
+    def setK(self, val):
+        return self._add_param('k', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class FmRateRecommender(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.recommendation.FmRateRecommender'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(FmRateRecommender, self).__init__(*args, **kwargs)
+        pass
+
+    def setItemCol(self, val):
+        return self._add_param('itemCol', val)
+
+    def setRecommCol(self, val):
+        return self._add_param('recommCol', val)
+
+    def setUserCol(self, val):
+        return self._add_param('userCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class FmRegressionModel(Model, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.regression.FmRegressionModel'
     OP_TYPE = 'FUNCTION'
@@ -1566,527 +2129,3 @@ class JsonToKv(Transformer, LocalPredictable):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-
-class JsonToVector(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.JsonToVector'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(JsonToVector, self).__init__(*args, **kwargs)
-        pass
-
-    def setJsonCol(self, val):
-        return self._add_param('jsonCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-
-class JsonValue(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.JsonValue'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(JsonValue, self).__init__(*args, **kwargs)
-        pass
-
-    def setJsonPath(self, val):
-        return self._add_param('jsonPath', val)
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputColTypes(self, val):
-        return self._add_param('outputColTypes', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSkipFailed(self, val):
-        return self._add_param('skipFailed', val)
-
-
-class KMeans(Estimator, HasLazyPrintModelInfo):
-    CLS_NAME = 'com.alibaba.alink.pipeline.clustering.KMeans'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KMeans, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setDistanceType(self, val):
-        return self._add_param('distanceType', val)
-
-    def setEpsilon(self, val):
-        return self._add_param('epsilon', val)
-
-    def setInitMode(self, val):
-        return self._add_param('initMode', val)
-
-    def setInitSteps(self, val):
-        return self._add_param('initSteps', val)
-
-    def setK(self, val):
-        return self._add_param('k', val)
-
-    def setMaxIter(self, val):
-        return self._add_param('maxIter', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setPredictionDistanceCol(self, val):
-        return self._add_param('predictionDistanceCol', val)
-
-    def setRandomSeed(self, val):
-        return self._add_param('randomSeed', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class KMeansModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.clustering.KMeansModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KMeansModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setPredictionDistanceCol(self, val):
-        return self._add_param('predictionDistanceCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class KnnClassificationModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.classification.KnnClassificationModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KnnClassificationModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setK(self, val):
-        return self._add_param('k', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class KnnClassifier(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.classification.KnnClassifier'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KnnClassifier, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setDistanceType(self, val):
-        return self._add_param('distanceType', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setK(self, val):
-        return self._add_param('k', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class KvToColumns(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.KvToColumns'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KvToColumns, self).__init__(*args, **kwargs)
-        pass
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class KvToCsv(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.KvToCsv'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KvToCsv, self).__init__(*args, **kwargs)
-        pass
-
-    def setCsvCol(self, val):
-        return self._add_param('csvCol', val)
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setCsvFieldDelimiter(self, val):
-        return self._add_param('csvFieldDelimiter', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class KvToJson(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.KvToJson'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KvToJson, self).__init__(*args, **kwargs)
-        pass
-
-    def setJsonCol(self, val):
-        return self._add_param('jsonCol', val)
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class KvToVector(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.KvToVector'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(KvToVector, self).__init__(*args, **kwargs)
-        pass
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-
-class LassoRegression(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.LassoRegression'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LassoRegression, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setLambda(self, val):
-        return self._add_param('lambda', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setEpsilon(self, val):
-        return self._add_param('epsilon', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setMaxIter(self, val):
-        return self._add_param('maxIter', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOptimMethod(self, val):
-        return self._add_param('optimMethod', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setStandardization(self, val):
-        return self._add_param('standardization', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-    def setWithIntercept(self, val):
-        return self._add_param('withIntercept', val)
-
-
-class LassoRegressionModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.regression.LassoRegressionModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(LassoRegressionModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class Lda(Estimator, HasLazyPrintModelInfo):
-    CLS_NAME = 'com.alibaba.alink.pipeline.clustering.Lda'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(Lda, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setTopicNum(self, val):
-        return self._add_param('topicNum', val)
-
-    def setAlpha(self, val):
-        return self._add_param('alpha', val)
-
-    def setBeta(self, val):
-        return self._add_param('beta', val)
-
-    def setLearningDecay(self, val):
-        return self._add_param('learningDecay', val)
-
-    def setMethod(self, val):
-        return self._add_param('method', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumIter(self, val):
-        return self._add_param('numIter', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOnlineLearningOffset(self, val):
-        return self._add_param('onlineLearningOffset', val)
-
-    def setOptimizeDocConcentration(self, val):
-        return self._add_param('optimizeDocConcentration', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setRandomSeed(self, val):
-        return self._add_param('randomSeed', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSubsamplingRate(self, val):
-        return self._add_param('subsamplingRate', val)
-
-    def setVocabSize(self, val):
-        return self._add_param('vocabSize', val)
-
