@@ -8,6 +8,64 @@ from ..lazy.has_lazy_print_train_info import HasLazyPrintTrainInfo
 from ..local_predictor import LocalPredictable
 
 
+class JsonToVector(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.JsonToVector'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonToVector, self).__init__(*args, **kwargs)
+        pass
+
+    def setJsonCol(self, val):
+        return self._add_param('jsonCol', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setHandleInvalid(self, val):
+        return self._add_param('handleInvalid', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorSize(self, val):
+        return self._add_param('vectorSize', val)
+
+
+class JsonValue(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.JsonValue'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(JsonValue, self).__init__(*args, **kwargs)
+        pass
+
+    def setJsonPath(self, val):
+        return self._add_param('jsonPath', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputColTypes(self, val):
+        return self._add_param('outputColTypes', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSkipFailed(self, val):
+        return self._add_param('skipFailed', val)
+
+
 class KMeans(Estimator, HasLazyPrintModelInfo):
     CLS_NAME = 'com.alibaba.alink.pipeline.clustering.KMeans'
     OP_TYPE = 'FUNCTION'
@@ -150,6 +208,9 @@ class KerasSequentialClassifier(Estimator):
     def setBatchSize(self, val):
         return self._add_param('batchSize', val)
 
+    def setBesteMetric(self, val):
+        return self._add_param('besteMetric', val)
+
     def setCheckpointFilePath(self, val):
         return self._add_param('checkpointFilePath', val)
 
@@ -186,6 +247,18 @@ class KerasSequentialClassifier(Estimator):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
+    def setSaveBestOnly(self, val):
+        return self._add_param('saveBestOnly', val)
+
+    def setSaveCheckpointsEpochs(self, val):
+        return self._add_param('saveCheckpointsEpochs', val)
+
+    def setSaveCheckpointsSecs(self, val):
+        return self._add_param('saveCheckpointsSecs', val)
+
+    def setValidationSplit(self, val):
+        return self._add_param('validationSplit', val)
+
 
 class KerasSequentialRegressionModel(Model, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.regression.KerasSequentialRegressionModel'
@@ -232,6 +305,9 @@ class KerasSequentialRegressor(Estimator):
     def setBatchSize(self, val):
         return self._add_param('batchSize', val)
 
+    def setBesteMetric(self, val):
+        return self._add_param('besteMetric', val)
+
     def setCheckpointFilePath(self, val):
         return self._add_param('checkpointFilePath', val)
 
@@ -265,6 +341,18 @@ class KerasSequentialRegressor(Estimator):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
+    def setSaveBestOnly(self, val):
+        return self._add_param('saveBestOnly', val)
+
+    def setSaveCheckpointsEpochs(self, val):
+        return self._add_param('saveCheckpointsEpochs', val)
+
+    def setSaveCheckpointsSecs(self, val):
+        return self._add_param('saveCheckpointsSecs', val)
+
+    def setValidationSplit(self, val):
+        return self._add_param('validationSplit', val)
+
 
 class KnnClassificationModel(Model, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.classification.KnnClassificationModel'
@@ -1939,178 +2027,3 @@ class RandomForestClassificationModel(Model, LocalPredictable):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-
-class RandomForestClassifier(Estimator, HasLazyPrintModelInfo):
-    CLS_NAME = 'com.alibaba.alink.pipeline.classification.RandomForestClassifier'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomForestClassifier, self).__init__(*args, **kwargs)
-        pass
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setCategoricalCols(self, val):
-        return self._add_param('categoricalCols', val)
-
-    def setCreateTreeMode(self, val):
-        return self._add_param('createTreeMode', val)
-
-    def setFeatureSubsamplingRatio(self, val):
-        return self._add_param('featureSubsamplingRatio', val)
-
-    def setMaxBins(self, val):
-        return self._add_param('maxBins', val)
-
-    def setMaxDepth(self, val):
-        return self._add_param('maxDepth', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMaxMemoryInMB(self, val):
-        return self._add_param('maxMemoryInMB', val)
-
-    def setMinInfoGain(self, val):
-        return self._add_param('minInfoGain', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinSamplesPerLeaf(self, val):
-        return self._add_param('minSamplesPerLeaf', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumSubsetFeatures(self, val):
-        return self._add_param('numSubsetFeatures', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setNumTrees(self, val):
-        return self._add_param('numTrees', val)
-
-    def setNumTreesOfGini(self, val):
-        return self._add_param('numTreesOfGini', val)
-
-    def setNumTreesOfInfoGain(self, val):
-        return self._add_param('numTreesOfInfoGain', val)
-
-    def setNumTreesOfInfoGainRatio(self, val):
-        return self._add_param('numTreesOfInfoGainRatio', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSubsamplingRatio(self, val):
-        return self._add_param('subsamplingRatio', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
-
-class RandomForestEncoder(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.feature.RandomForestEncoder'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(RandomForestEncoder, self).__init__(*args, **kwargs)
-        pass
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setCategoricalCols(self, val):
-        return self._add_param('categoricalCols', val)
-
-    def setCreateTreeMode(self, val):
-        return self._add_param('createTreeMode', val)
-
-    def setFeatureSubsamplingRatio(self, val):
-        return self._add_param('featureSubsamplingRatio', val)
-
-    def setMaxBins(self, val):
-        return self._add_param('maxBins', val)
-
-    def setMaxDepth(self, val):
-        return self._add_param('maxDepth', val)
-
-    def setMaxLeaves(self, val):
-        return self._add_param('maxLeaves', val)
-
-    def setMaxMemoryInMB(self, val):
-        return self._add_param('maxMemoryInMB', val)
-
-    def setMinInfoGain(self, val):
-        return self._add_param('minInfoGain', val)
-
-    def setMinSampleRatioPerChild(self, val):
-        return self._add_param('minSampleRatioPerChild', val)
-
-    def setMinSamplesPerLeaf(self, val):
-        return self._add_param('minSamplesPerLeaf', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumSubsetFeatures(self, val):
-        return self._add_param('numSubsetFeatures', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setNumTrees(self, val):
-        return self._add_param('numTrees', val)
-
-    def setNumTreesOfGini(self, val):
-        return self._add_param('numTreesOfGini', val)
-
-    def setNumTreesOfInfoGain(self, val):
-        return self._add_param('numTreesOfInfoGain', val)
-
-    def setNumTreesOfInfoGainRatio(self, val):
-        return self._add_param('numTreesOfInfoGainRatio', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSubsamplingRatio(self, val):
-        return self._add_param('subsamplingRatio', val)
-
-    def setWeightCol(self, val):
-        return self._add_param('weightCol', val)
-
