@@ -8,6 +8,181 @@ from ..lazy.has_lazy_print_train_info import HasLazyPrintTrainInfo
 from ..local_predictor import LocalPredictable
 
 
+class RandomForestClassifier(Estimator, HasLazyPrintModelInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.classification.RandomForestClassifier'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestClassifier, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setCreateTreeMode(self, val):
+        return self._add_param('createTreeMode', val)
+
+    def setFeatureSubsamplingRatio(self, val):
+        return self._add_param('featureSubsamplingRatio', val)
+
+    def setMaxBins(self, val):
+        return self._add_param('maxBins', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMaxMemoryInMB(self, val):
+        return self._add_param('maxMemoryInMB', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumSubsetFeatures(self, val):
+        return self._add_param('numSubsetFeatures', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setNumTrees(self, val):
+        return self._add_param('numTrees', val)
+
+    def setNumTreesOfGini(self, val):
+        return self._add_param('numTreesOfGini', val)
+
+    def setNumTreesOfInfoGain(self, val):
+        return self._add_param('numTreesOfInfoGain', val)
+
+    def setNumTreesOfInfoGainRatio(self, val):
+        return self._add_param('numTreesOfInfoGainRatio', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSubsamplingRatio(self, val):
+        return self._add_param('subsamplingRatio', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+
+class RandomForestEncoder(Estimator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.RandomForestEncoder'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestEncoder, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setCreateTreeMode(self, val):
+        return self._add_param('createTreeMode', val)
+
+    def setFeatureSubsamplingRatio(self, val):
+        return self._add_param('featureSubsamplingRatio', val)
+
+    def setMaxBins(self, val):
+        return self._add_param('maxBins', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMaxMemoryInMB(self, val):
+        return self._add_param('maxMemoryInMB', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumSubsetFeatures(self, val):
+        return self._add_param('numSubsetFeatures', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setNumTrees(self, val):
+        return self._add_param('numTrees', val)
+
+    def setNumTreesOfGini(self, val):
+        return self._add_param('numTreesOfGini', val)
+
+    def setNumTreesOfInfoGain(self, val):
+        return self._add_param('numTreesOfInfoGain', val)
+
+    def setNumTreesOfInfoGainRatio(self, val):
+        return self._add_param('numTreesOfInfoGainRatio', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSubsamplingRatio(self, val):
+        return self._add_param('subsamplingRatio', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+
 class RandomForestEncoderModel(Model, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.feature.RandomForestEncoderModel'
     OP_TYPE = 'FUNCTION'
@@ -791,6 +966,9 @@ class StringIndexer(Estimator):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
     def setStringOrderType(self, val):
         return self._add_param('stringOrderType', val)
 
@@ -1056,9 +1234,15 @@ class TFTableModelTrainer(Estimator):
         super(TFTableModelTrainer, self).__init__(*args, **kwargs)
         pass
 
+    def setMainScriptFile(self, val):
+        return self._add_param('mainScriptFile', val)
+
     def setOutputSchemaStr(self, val):
         return self._add_param('outputSchemaStr', val)
 
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
+
     def setGraphDefTag(self, val):
         return self._add_param('graphDefTag', val)
 
@@ -1068,9 +1252,6 @@ class TFTableModelTrainer(Estimator):
     def setIntraOpParallelism(self, val):
         return self._add_param('intraOpParallelism', val)
 
-    def setMainScriptFile(self, val):
-        return self._add_param('mainScriptFile', val)
-
     def setNumPSs(self, val):
         return self._add_param('numPSs', val)
 
@@ -1092,9 +1273,6 @@ class TFTableModelTrainer(Estimator):
     def setSignatureDefKey(self, val):
         return self._add_param('signatureDefKey', val)
 
-    def setUserFiles(self, val):
-        return self._add_param('userFiles', val)
-
     def setUserParams(self, val):
         return self._add_param('userParams', val)
 
@@ -1268,6 +1446,47 @@ class TextNearestNeighborModel(Model, LocalPredictable):
         return self._add_param('topN', val)
 
 
+class TextSimilarityPairwise(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.similarity.TextSimilarityPairwise'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TextSimilarityPairwise, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setLambda(self, val):
+        return self._add_param('lambda', val)
+
+    def setMetric(self, val):
+        return self._add_param('metric', val)
+
+    def setNumBucket(self, val):
+        return self._add_param('numBucket', val)
+
+    def setNumHashTables(self, val):
+        return self._add_param('numHashTables', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setWindowSize(self, val):
+        return self._add_param('windowSize', val)
+
+
 class Tokenizer(Transformer, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.nlp.Tokenizer'
     OP_TYPE = 'FUNCTION'
@@ -1637,81 +1856,3 @@ class VectorImputerModel(Model, LocalPredictable):
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-
-class VectorInteraction(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorInteraction'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorInteraction, self).__init__(*args, **kwargs)
-        pass
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorMaxAbsScaler(Estimator, HasLazyPrintModelInfo):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorMaxAbsScaler'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMaxAbsScaler, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-
-class VectorMaxAbsScalerModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorMaxAbsScalerModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMaxAbsScalerModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
