@@ -1,4 +1,4 @@
-from pyalink.alink.pipeline.common.pipeline_op_2 import _OneVsRest
+from .common import OneVsRest as _OneVsRest
 
 
 class OneVsRest(_OneVsRest):
