@@ -301,6 +301,20 @@ class AlsUsersPerItemRecommStreamOp(BaseModelStreamOp):
         return self._add_param('reservedCols', val)
 
 
+class AppendIdStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.AppendIdStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(AppendIdStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setIdCol(self, val):
+        return self._add_param('idCol', val)
+
+
 class ArimaStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.timeseries.ArimaStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -477,9 +491,6 @@ class BertTextEmbeddingStreamOp(StreamOperator):
         super(BertTextEmbeddingStreamOp, self).__init__(*args, **kwargs)
         pass
 
-    def setModelPath(self, val):
-        return self._add_param('modelPath', val)
-
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -797,6 +808,17 @@ class CatalogSourceStreamOp(StreamOperator):
         return self._add_param('catalogObject', val)
 
 
+class CollectSinkStreamOp(BaseSinkStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.sink.CollectSinkStreamOp'
+    OP_TYPE = 'SINK'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(CollectSinkStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+
 class ColumnsToCsvStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.ColumnsToCsvStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -1225,11 +1247,14 @@ class DLLauncherStreamOp(StreamOperator):
     def setEntryFunc(self, val):
         return self._add_param('entryFunc', val)
 
+    def setMainScriptFile(self, val):
+        return self._add_param('mainScriptFile', val)
+
     def setOutputSchemaStr(self, val):
         return self._add_param('outputSchemaStr', val)
 
-    def setScript(self, val):
-        return self._add_param('script', val)
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
 
     def setIntraOpParallelism(self, val):
         return self._add_param('intraOpParallelism', val)
@@ -1243,11 +1268,8 @@ class DLLauncherStreamOp(StreamOperator):
     def setPythonEnv(self, val):
         return self._add_param('pythonEnv', val)
 
-    def setUserDefinedParams(self, val):
-        return self._add_param('userDefinedParams', val)
-
-    def setUserFiles(self, val):
-        return self._add_param('userFiles', val)
+    def setUserParams(self, val):
+        return self._add_param('userParams', val)
 
 
 class DecisionTreePredictStreamOp(BaseModelStreamOp):
@@ -1353,6 +1375,15 @@ class DocCountVectorizerPredictStreamOp(BaseModelStreamOp):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1455,52 +1486,3 @@ class EqualWidthDiscretizerPredictStreamOp(BaseModelStreamOp):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-
-class EvalBinaryClassStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.evaluation.EvalBinaryClassStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(EvalBinaryClassStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setPositiveLabelValueString(self, val):
-        return self._add_param('positiveLabelValueString', val)
-
-    def setTimeInterval(self, val):
-        return self._add_param('timeInterval', val)
-
-
-class EvalMultiClassStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.evaluation.EvalMultiClassStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(EvalMultiClassStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setTimeInterval(self, val):
-        return self._add_param('timeInterval', val)
-
