@@ -6,11 +6,6 @@ from ..common.utils.packages import is_flink_1_9
 from ..py4j_util import get_java_class
 
 
-def _to_dill_base64(v):
-    import dill
-    return ensure_unicode(base64.b64encode(dill.dumps(v, recurse=True)))
-
-
 def _to_cloudpickle_base64(v):
     import cloudpickle
     return ensure_unicode(base64.b64encode(cloudpickle.dumps(v)))
@@ -59,13 +54,11 @@ def register_pyflink_function(name, func, env_type):
     _java_register_function(name, j_func, env_type)
 
 
-def _to_judf(name, func, result_type, class_object_type="DILL_BASE64"):
+def _to_judf(name, func, result_type, class_object_type):
     if not callable(func) and not hasattr(func, "eval"):
         raise ValueError("Invalid function: not a callable or an object with attr eval")
 
-    if class_object_type == "DILL_BASE64":
-        class_object = _to_dill_base64(func)
-    elif class_object_type == "CLOUDPICKLE_BASE64":
+    if class_object_type == "CLOUDPICKLE_BASE64":
         class_object = _to_cloudpickle_base64(func)
     else:
         raise NotImplementedError
@@ -79,13 +72,11 @@ def _to_judf(name, func, result_type, class_object_type="DILL_BASE64"):
     return j_python_udf_factory_cls.makeScalarFunction(name, result_type, config_json)
 
 
-def _to_judtf(name, func, result_types, class_object_type="DILL_BASE64"):
+def _to_judtf(name, func, result_types, class_object_type):
     if not callable(func) and not hasattr(func, "eval"):
         raise ValueError("Invalid function: not a callable or an object with attr eval")
 
-    if class_object_type == "DILL_BASE64":
-        class_object = _to_dill_base64(func)
-    elif class_object_type == "CLOUDPICKLE_BASE64":
+    if class_object_type == "CLOUDPICKLE_BASE64":
         class_object = _to_cloudpickle_base64(func)
     else:
         raise NotImplementedError
